@@ -259,13 +259,13 @@ class OptionValuationResultTablePlot:
     def __init__(self, val_results: List[OptionValuationResult],
                  val_inputs: Dict[str, OptionValuation]):
 
-        tag2id = {tag: ov.option_valuation_id for tag, ov in val_inputs.items()}
+        tag2id = {tag: ov.valuation_id for tag, ov in val_inputs.items()}
         id2tag = {v: k for k, v in tag2id.items()}
 
         self.results = val_results
         self.inputs = val_inputs
 
-        res_tags = [id2tag[vr.option_valuation_id] for vr in val_results]
+        res_tags = [id2tag[vr.valuation_id] for vr in val_results]
         results_table = convert_object_list_to_df(val_results).T
         results_table.columns = res_tags
         results_table = results_table[tag2id.keys()].copy()
