@@ -161,17 +161,18 @@ class OptionValuation(AssetValuation):
 
     option_type: Optional[OptionType]
     """
-    Whether we are pricing a PUT or CALL option.
+    Whether we are pricing a PUT or CALL option. Not required if optionAssetId provided.
     """
 
     option_style: Optional[OptionStyle] = OptionStyle.EUROPEAN
     """
-    The variety of option being priced. Our pricer only supports EUROPEAN at this time, so defaults accordingly.
+    The variety of option being priced. Not required if optionAssetId provided.
+    Our pricer only supports EUROPEAN at this time, so defaults accordingly.
     """
 
-    contract_size: Optional[PositiveFloat] = 1
+    contract_size: Optional[PositiveFloat]
     """
-    For scaling purposes, the # of underlying per contract. Only used if option_asset_id is not set, otherwise it's
+    For scaling purposes, the # of underlying per contract. Not required if optionAssetId provided, otherwise it's
     loaded from the contract specification in the database.
     """
 
@@ -211,12 +212,13 @@ class ValuationRequest(CamelModel):
     as_of_time: Optional[datetime]
     """
     The as-of time to use for loading all marketdata, surfaces, yield curves and refdata from the database.
-    Defaulted to the latest up to this time.
+    Defaults to the latest up to this time.
     """
 
     model_config_id: Optional[UUID]
     """
     The specific derivatives analytics model configuration to load; this is used to drive defaults.
+    Defaults to system's recommended config.
     """
 
     base_currency_id: Optional[UUID]
@@ -228,6 +230,7 @@ class ValuationRequest(CamelModel):
     """
     How to derive the discount rate: from the projection rate (self-discounting),
     or from pre-built discounting curves either provided in API or loaded from the system.
+    Defaults to self-discounting.
     """
 
     projection_method: Optional[ProjectionMethod]
@@ -267,12 +270,12 @@ class ValuationRequest(CamelModel):
 
     vol_model: Optional[VolModel] = VolModel.SVI
     """
-    The volatility model used for valuation purposes.
+    The volatility model used for valuation purposes. Defaults to SVI.
     """
 
     strike_type: Optional[StrikeType] = StrikeType.LOG_MONEYNESS
     """
-    The strike representation.
+    The strike representation. Defaults to log-moneyness.
     """
 
     @validator('vol_surface', always=True)
@@ -516,12 +519,36 @@ class StrategyValuationResult(CamelModel):
     The sum of the present values of the strategy legs, i.e. the theoretical strategy value.
     """
 
-    notional_value: float
+    delta_qty: float
     """
-    The sum of the base currency notionals of all legs in the strategy.
+    Sum of leg-level delta_qty's
     """
 
+    delta_ccy: float
+    """
+    Sum of leg-level delta_ccy's
+    """
+
+    gamma_ccy: float
+    """
+    Sum of leg-level gamma_ccy's
+    """
+
+    vega_ccy: float
+    """Sum of leg-level vega_ccy's, ignoring leg-level differences in expiries and strikes
+    """
+
+    rho_ccy: float
+    """
+    Sum of leg-level rho_ccy's, ignoring leg-level differences in expiries
+    """
+
+    theta_ccy: float
+    """
+    Sum of leg-level theta_ccy's
+    """
+
+    leg_results: List[OptionValuationResult]
     """
     Per-leg valuation results, e.g. the individual option values and greeks.
     """
-    leg_results: List[OptionValuationResult]
